<?php

namespace MCPEStore;

use pocketmine\Player;
use pocketmine\utils\TextFormat as TF;

class APIEndpoint
{
    private $APIRequest;

    public function __construct()
    {
        $this->APIRequest = new APIRequest();
    }

    /**
     * Verifica se a API está realmente ativa.
     * @return bool
     */
    public function getStatusAPI()
    {  
        $response = $this->APIRequest->send('GET', "/status");

        return (isset($response->status) && $response->status === true);
    }

    /**
     * Verifica se a API está realmente ativa.
     * @return bool
     */
    public function verifyServer(string $uuid, $sender)
    {  
        $response = $this->APIRequest->send('POST', "/verify/{$uuid}");

        $isSuccess = isset($response->success) && $response->success === true;
        $message   = isset($response->message) ? $response->message : "Erro desconhecido";

        if (!$isSuccess) {
            $sender->sendMessage(TF::RED . "Não foi possível verificar o servidor.");
            $sender->sendMessage(TF::RED . "Motivo: {$message}");
            return false;
        }

        $sender->sendMessage(TF::GREEN . "Servidor verificado com sucesso!");
        return true;
    }

    /**
     * Retorna as compras aprovados pelo jogador, mas que não foram entregues.
     * @return array $response->items;
     */
    public function getPlayerItems(Player $player, string $uuid)
    {
        $response = $this->APIRequest->send('GET', "/items?nickname=".$player->getName()."&status=approved&is_delivered=0", $uuid);

        if (!isset($response->items) || !$response->success) {
            return [];
        } 

        return $response->items;
    }

    /**
     * Define um pedido como entregue
     * @return bool
     */
    public function updateItemsDelivered(int $itemId, string $uuid)
    {
        $response = $this->APIRequest->send('PATCH', "/items/{$itemId}", $uuid);

        return (isset($response->success) && $response->success === true);
    }
}