<?php

namespace MCPEStore;

use pocketmine\plugin\PluginBase;
use pocketmine\event\Listener;
use pocketmine\event\player\PlayerJoinEvent;
use pocketmine\Server;
use pocketmine\command\ConsoleCommandSender;
use pocketmine\command\Command;
use pocketmine\command\CommandSender;
use pocketmine\utils\TextFormat as TF;

class Main extends PluginBase implements Listener
{
    private $config;
    private $isEnabled;
    private $APIEndpoint;

    public function __construct()
    {
        $this->APIEndpoint = new APIEndpoint();
    }

    public function onEnable()
    {
        $this->getServer()->getPluginManager()->registerEvents($this, $this);

        // Desabilita o plugin caso não haja compatibilidade com "cURL":
        if (!function_exists('curl_version') || !extension_loaded('curl')) {
            $this->getLogger()->info($this->config['messages']['prefix'] . " Plugin Desativado - Servidor não tem cURL habilitado.");
            $this->onDisable();
        }

        $this->config    = $this->getConfig()->getAll();
        $this->isEnabled = $this->APIEndpoint->getStatusAPI();

        // Desabilita o plugin caso a API esteja offline.
        if (!$this->isEnabled) {
            $this->getLogger()->info($this->config['messages']['prefix'] . " Plugin Desativado - API OFFLINE.");
            $this->onDisable();
        }
    }

    public function onCommand(CommandSender $sender, Command $command, $label, array $args)
    {
        if ($command->getName() !== "market") {
            return;
        }
    
        if (!$this->isEnabled) {
            $sender->sendMessage($this->config['messages']['prefix'] . " Plugin não habilitado");
            return;
        }
    
        if (empty($args)) {
            return; // Retorna sem exibir a mensagem de uso
        }
    
        $action = strtolower(rtrim($args[0]));
    
        switch ($action) {
            case "verify":
                if (!$sender->hasPermission("market.verify")) {
                    $sender->sendMessage("Você não tem permissão para executar este comando.");
                    return;
                }
                $this->actionServerVerification($sender);
                break;
    
            case "receive":
                if (!$sender->hasPermission("market.receive")) {
                    $sender->sendMessage("Você não tem permissão para executar este comando.");
                    return;
                }
                $this->actionReceiveItems($sender);
                break;
    
            default:
                $actions = $sender->hasPermission("market.verify") ? "<verify|receive>" : "<receive>";
                $sender->sendMessage($this->config['messages']['prefix'] . " Ação inválida. Use: /market {$actions}");
                break;
        }
    }

    private function actionServerVerification($sender)
    {
        $sender->sendMessage(TF::YELLOW . $this->config['messages']['prefix'] . " Verificando...");
    
        $this->APIEndpoint->verifyServer($this->config['uuid'], $sender);
    }
    
    private function actionReceiveItems($sender)
    {
        $player = $sender->getPlayer();

        $sender->sendMessage($this->config['messages']['prefix']." ".TF::YELLOW . "Obtendo produtos..." . $player->getName());

        $items = $this->APIEndpoint->getPlayerItems($player, $this->config['uuid']);

        if (!$items) {
            $sender->sendMessage(TF::RED . $this->config['messages']['prefix'] . " " . $this->config['messages']['error']['no_items']);
            return;
        }

        foreach ($items as $item) {
            foreach ($item->products as $product) {
                $this->getServer()->dispatchCommand(new ConsoleCommandSender(), $product->cmd_console);
                // $sender->sendMessage(TF::YELLOW . $this->config['messages']['prefix'] . " Produto resgatado: {$product->name}");
            }

            $this->APIEndpoint->updateItemsDelivered($item->id, $this->config['uuid']);
        }

        $sender->sendMessage(TF::GREEN . $this->config['messages']['prefix'] . " " . $this->config['messages']['success']['actived']);
    }

    public function onDisable()
    {
        // $this->getLogger()->info("Plugin Desabilitado");
    }
}
